@@ -34,6 +34,8 @@ class CloudFormation:
     parameters = []
     for export in self.get_exports(stack_prefix, stack_name):
       parameter_name = export['Name'].replace(self.get_stack_prefix(stack_prefix, stack_name), "")
+      if not stack_name:
+        parameter_name = "-".join(parameter_name.split("-")[1:])
       parameters.append({
         "Name": parameter_name,
         "Value": export["Value"]
